@@ -19,14 +19,15 @@
  */
 
 #ifdef HAVE_CONFIG_H
-#include <config.h>
+#include "config.h"
 #endif
 
-#include <glib.h>
-#include <glib-object.h>
+#include "garcon-menu-item.h"
+#include "garcon-menu-node.h"
+#include "garcon-visibility.h"
 
-#include <garcon/garcon-menu-item.h>
-#include <garcon/garcon-menu-node.h>
+#include <glib-object.h>
+#include <glib.h>
 
 
 
@@ -39,16 +40,20 @@ enum
 
 
 
-static void garcon_menu_node_finalize     (GObject             *object);
-static void garcon_menu_node_get_property (GObject             *object,
-                                           guint                prop_id,
-                                           GValue              *value,
-                                           GParamSpec          *pspec);
-static void garcon_menu_node_set_property (GObject             *object,
-                                           guint                prop_id,
-                                           const GValue        *value,
-                                           GParamSpec          *pspec);
-static void garcon_menu_node_free_data    (GarconMenuNode      *node);
+static void
+garcon_menu_node_finalize (GObject *object);
+static void
+garcon_menu_node_get_property (GObject *object,
+                               guint prop_id,
+                               GValue *value,
+                               GParamSpec *pspec);
+static void
+garcon_menu_node_set_property (GObject *object,
+                               guint prop_id,
+                               const GValue *value,
+                               GParamSpec *pspec);
+static void
+garcon_menu_node_free_data (GarconMenuNode *node);
 
 
 
@@ -63,14 +68,14 @@ union _GarconMenuNodeData
   struct
   {
     GarconMenuMergeFileType type;
-    gchar                  *filename;
+    gchar *filename;
   } merge_file;
-  gchar                    *string;
+  gchar *string;
 };
 
 struct _GarconMenuNode
 {
-  GObject            __parent__;
+  GObject __parent__;
 
   GarconMenuNodeType node_type;
   GarconMenuNodeData data;
@@ -81,9 +86,8 @@ struct _GarconMenuNode
 GType
 garcon_menu_node_type_get_type (void)
 {
-  static GType      type = G_TYPE_INVALID;
-  static GEnumValue values[] =
-  {
+  static GType type = G_TYPE_INVALID;
+  static GEnumValue values[] = {
     { GARCON_MENU_NODE_TYPE_INVALID, "GARCON_MENU_NODE_TYPE_INVALID", "Invalid" },
     { GARCON_MENU_NODE_TYPE_MENU, "GARCON_MENU_NODE_TYPE_MENU", "Menu" },
     { GARCON_MENU_NODE_TYPE_NAME, "GARCON_MENU_NODE_TYPE_NAME", "Name" },
@@ -147,8 +151,8 @@ garcon_menu_node_class_init (GarconMenuNodeClass *klass)
                                                       "node-type",
                                                       garcon_menu_node_type_get_type (),
                                                       GARCON_MENU_NODE_TYPE_MENU,
-                                                      G_PARAM_READWRITE |
-                                                      G_PARAM_STATIC_STRINGS));
+                                                      G_PARAM_READWRITE
+                                                        | G_PARAM_STATIC_STRINGS));
 }
 
 
@@ -173,9 +177,9 @@ garcon_menu_node_finalize (GObject *object)
 
 
 static void
-garcon_menu_node_get_property (GObject    *object,
-                               guint       prop_id,
-                               GValue     *value,
+garcon_menu_node_get_property (GObject *object,
+                               guint prop_id,
+                               GValue *value,
                                GParamSpec *pspec)
 {
   GarconMenuNode *node = GARCON_MENU_NODE (object);
@@ -195,10 +199,10 @@ garcon_menu_node_get_property (GObject    *object,
 
 
 static void
-garcon_menu_node_set_property (GObject      *object,
-                               guint         prop_id,
+garcon_menu_node_set_property (GObject *object,
+                               guint prop_id,
                                const GValue *value,
-                               GParamSpec   *pspec)
+                               GParamSpec *pspec)
 {
   GarconMenuNode *node = GARCON_MENU_NODE (object);
 
@@ -225,17 +229,25 @@ garcon_menu_node_new (GarconMenuNodeType node_type)
 
 
 
-GarconMenuNodeType garcon_menu_node_get_node_type (GarconMenuNode *node)
+GarconMenuNodeType
+garcon_menu_node_get_node_type (GarconMenuNode *node)
 {
   g_return_val_if_fail (GARCON_IS_MENU_NODE (node), 0);
   return node->node_type;
 }
 
 
-
+/**
+ * garcon_menu_node_create:
+ * @node_type: a #GarconMenuNodeType
+ * @first_value:
+ * @...:
+ *
+ * Returns: (transfer full): a #GarconMenuNode
+ */
 GarconMenuNode *
 garcon_menu_node_create (GarconMenuNodeType node_type,
-                         gpointer           first_value,
+                         gpointer first_value,
                          ...)
 {
   GarconMenuNode *node;
@@ -274,9 +286,16 @@ garcon_menu_node_create (GarconMenuNodeType node_type,
 }
 
 
-
+/**
+ * garcon_menu_node_copy:
+ * @node: a #GarconMenuNode
+ * @data:
+ *
+ * Returns: (transfer full): a #GarconMenuNode
+ */
 GarconMenuNode *
-garcon_menu_node_copy (GarconMenuNode *node)
+garcon_menu_node_copy (GarconMenuNode *node,
+                       gpointer data)
 {
   GarconMenuNode *copy;
 
@@ -360,7 +379,7 @@ garcon_menu_node_get_string (GarconMenuNode *node)
 
 void
 garcon_menu_node_set_string (GarconMenuNode *node,
-                             const gchar    *value)
+                             const gchar *value)
 {
   g_return_if_fail (GARCON_IS_MENU_NODE (node));
   g_return_if_fail (value != NULL);
@@ -382,7 +401,7 @@ garcon_menu_node_get_merge_file_type (GarconMenuNode *node)
 
 
 void
-garcon_menu_node_set_merge_file_type (GarconMenuNode         *node,
+garcon_menu_node_set_merge_file_type (GarconMenuNode *node,
                                       GarconMenuMergeFileType type)
 {
   g_return_if_fail (GARCON_IS_MENU_NODE (node));
@@ -404,7 +423,7 @@ garcon_menu_node_get_merge_file_filename (GarconMenuNode *node)
 
 void
 garcon_menu_node_set_merge_file_filename (GarconMenuNode *node,
-                                          const gchar    *filename)
+                                          const gchar *filename)
 {
   g_return_if_fail (GARCON_IS_MENU_NODE (node));
   g_return_if_fail (filename != NULL);
@@ -419,15 +438,15 @@ garcon_menu_node_set_merge_file_filename (GarconMenuNode *node,
 typedef struct
 {
   GarconMenuNodeType type;
-  GNode             *self;
-  gpointer           value;
+  GNode *self;
+  gpointer value;
 } Pair;
 
 
 
 static gboolean
 collect_children (GNode *node,
-                  Pair  *pair)
+                  Pair *pair)
 {
   if (node == pair->self)
     return FALSE;
@@ -439,17 +458,24 @@ collect_children (GNode *node,
 }
 
 
-
+/**
+ * garcon_menu_node_tree_get_child_node: (skip)
+ * @tree: #GNode instance
+ * @type: type for the menu nodes
+ * @reverse:
+ *
+ * Returns: a #GNode if @type is valid menu nodes type.
+ */
 GNode *
-garcon_menu_node_tree_get_child_node (GNode             *tree,
+garcon_menu_node_tree_get_child_node (GNode *tree,
                                       GarconMenuNodeType type,
-                                      gboolean           reverse)
+                                      gboolean reverse)
 {
-  GNode *child;
+  GNode *child = NULL;
 
   if (reverse)
     {
-      for (child = g_node_last_child (tree); 
+      for (child = g_node_last_child (tree);
            child != NULL;
            child = g_node_prev_sibling (child))
         {
@@ -468,15 +494,22 @@ garcon_menu_node_tree_get_child_node (GNode             *tree,
         }
     }
 
-  return NULL;
+  return child;
 }
 
 
-
+/**
+ * garcon_menu_node_tree_get_child_nodes:
+ * @tree: a GNode
+ * @type: type for the menu nodes
+ * @reverse:
+ *
+ * Returns: (element-type GNode) (transfer full): list of #GNode
+ */
 GList *
-garcon_menu_node_tree_get_child_nodes (GNode             *tree,
+garcon_menu_node_tree_get_child_nodes (GNode *tree,
                                        GarconMenuNodeType type,
-                                       gboolean           reverse)
+                                       gboolean reverse)
 {
   Pair pair;
 
@@ -491,14 +524,14 @@ garcon_menu_node_tree_get_child_nodes (GNode             *tree,
   if (!reverse && pair.value != NULL)
     pair.value = g_list_reverse (pair.value);
 
-  return pair.value;
+  return (GList *) pair.value;
 }
 
 
 
 static gboolean
 collect_strings (GNode *node,
-                 Pair  *pair)
+                 Pair *pair)
 {
   gpointer string;
 
@@ -515,11 +548,18 @@ collect_strings (GNode *node,
 }
 
 
-
+/**
+ * garcon_menu_node_tree_get_string_children:
+ * @tree: a #GNode instance
+ * @type: type for the menu nodes
+ * @reverse:
+ *
+ * Returns: (element-type GNode) (transfer container): list of #GNode
+ */
 GList *
-garcon_menu_node_tree_get_string_children (GNode             *tree,
+garcon_menu_node_tree_get_string_children (GNode *tree,
                                            GarconMenuNodeType type,
-                                           gboolean           reverse)
+                                           gboolean reverse)
 {
   Pair pair;
 
@@ -534,14 +574,14 @@ garcon_menu_node_tree_get_string_children (GNode             *tree,
   if (!reverse && pair.value != NULL)
     pair.value = g_list_reverse (pair.value);
 
-  return pair.value;
+  return (GList *) pair.value;
 }
 
 
 
 static gboolean
 collect_boolean (GNode *node,
-                 Pair  *pair)
+                 Pair *pair)
 {
   if (node == pair->self)
     return FALSE;
@@ -558,7 +598,7 @@ collect_boolean (GNode *node,
 
 
 gboolean
-garcon_menu_node_tree_get_boolean_child (GNode             *tree,
+garcon_menu_node_tree_get_boolean_child (GNode *tree,
                                          GarconMenuNodeType type)
 {
   Pair pair;
@@ -577,7 +617,7 @@ garcon_menu_node_tree_get_boolean_child (GNode             *tree,
 
 static gboolean
 collect_string (GNode *node,
-                Pair  *pair)
+                Pair *pair)
 {
   const gchar **string = pair->value;
 
@@ -596,10 +636,10 @@ collect_string (GNode *node,
 
 
 const gchar *
-garcon_menu_node_tree_get_string_child (GNode             *tree,
+garcon_menu_node_tree_get_string_child (GNode *tree,
                                         GarconMenuNodeType type)
 {
-  Pair         pair;
+  Pair pair;
   const gchar *string = NULL;
 
   pair.type = type;
@@ -615,10 +655,10 @@ garcon_menu_node_tree_get_string_child (GNode             *tree,
 
 
 gboolean
-garcon_menu_node_tree_rule_matches (GNode          *node,
+garcon_menu_node_tree_rule_matches (GNode *node,
                                     GarconMenuItem *item)
 {
-  GNode   *child;
+  GNode *child;
   gboolean matches = FALSE;
   gboolean child_matches = FALSE;
 
@@ -665,9 +705,6 @@ garcon_menu_node_tree_rule_matches (GNode          *node,
 
 
 
-
-
-
 GarconMenuNodeType
 garcon_menu_node_tree_get_node_type (GNode *tree)
 {
@@ -694,23 +731,23 @@ garcon_menu_node_tree_get_string (GNode *tree)
 
 
 void
-garcon_menu_node_tree_set_string (GNode       *tree,
+garcon_menu_node_tree_set_string (GNode *tree,
                                   const gchar *value)
 {
   GarconMenuNodeType type;
 
   type = garcon_menu_node_tree_get_node_type (tree);
 
-  g_return_if_fail (type == GARCON_MENU_NODE_TYPE_NAME ||
-                    type == GARCON_MENU_NODE_TYPE_DIRECTORY ||
-                    type == GARCON_MENU_NODE_TYPE_DIRECTORY_DIR ||
-                    type == GARCON_MENU_NODE_TYPE_APP_DIR ||
-                    type == GARCON_MENU_NODE_TYPE_FILENAME ||
-                    type == GARCON_MENU_NODE_TYPE_CATEGORY ||
-                    type == GARCON_MENU_NODE_TYPE_OLD ||
-                    type == GARCON_MENU_NODE_TYPE_NEW ||
-                    type == GARCON_MENU_NODE_TYPE_MENUNAME ||
-                    type == GARCON_MENU_NODE_TYPE_MERGE_DIR);
+  g_return_if_fail (type == GARCON_MENU_NODE_TYPE_NAME
+                    || type == GARCON_MENU_NODE_TYPE_DIRECTORY
+                    || type == GARCON_MENU_NODE_TYPE_DIRECTORY_DIR
+                    || type == GARCON_MENU_NODE_TYPE_APP_DIR
+                    || type == GARCON_MENU_NODE_TYPE_FILENAME
+                    || type == GARCON_MENU_NODE_TYPE_CATEGORY
+                    || type == GARCON_MENU_NODE_TYPE_OLD
+                    || type == GARCON_MENU_NODE_TYPE_NEW
+                    || type == GARCON_MENU_NODE_TYPE_MENUNAME
+                    || type == GARCON_MENU_NODE_TYPE_MERGE_DIR);
 
   garcon_menu_node_set_string (tree->data, value);
 }
@@ -720,7 +757,7 @@ GarconMenuLayoutMergeType
 garcon_menu_node_tree_get_layout_merge_type (GNode *tree)
 {
   g_return_val_if_fail (garcon_menu_node_tree_get_node_type (tree) == GARCON_MENU_NODE_TYPE_MERGE, 0);
-  return ((GarconMenuNode *)tree->data)->data.layout_merge_type;
+  return ((GarconMenuNode *) tree->data)->data.layout_merge_type;
 }
 
 
@@ -744,8 +781,8 @@ garcon_menu_node_tree_get_merge_file_filename (GNode *tree)
 
 
 void
-garcon_menu_node_tree_set_merge_file_filename (GNode       *tree,
-                                                  const gchar *filename)
+garcon_menu_node_tree_set_merge_file_filename (GNode *tree,
+                                               const gchar *filename)
 {
   g_return_if_fail (garcon_menu_node_tree_get_node_type (tree) == GARCON_MENU_NODE_TYPE_MERGE_FILE);
   garcon_menu_node_set_merge_file_filename (tree->data, filename);
@@ -798,7 +835,12 @@ garcon_menu_node_tree_compare (GNode *tree,
 }
 
 
-
+/**
+ * garcon_menu_node_tree_copy: (skip)
+ * @tree: a #GNode
+ *
+ * Recursively copies a #GNode.
+ */
 GNode *
 garcon_menu_node_tree_copy (GNode *tree)
 {
@@ -808,7 +850,8 @@ garcon_menu_node_tree_copy (GNode *tree)
 
 
 static gboolean
-free_children (GNode *tree)
+free_children (GNode *tree,
+               gpointer data)
 {
   garcon_menu_node_tree_free_data (tree);
   return FALSE;
@@ -837,3 +880,5 @@ garcon_menu_node_tree_free_data (GNode *tree)
     g_object_unref (tree->data);
 }
 
+#define __GARCON_MENU_NODE_C__
+#include "garcon-visibility.c"
